summaryrefslogtreecommitdiff
path: root/taskflow/patterns/unordered_flow.py
diff options
context:
space:
mode:
authorJoshua Harlow <harlowja@gmail.com>2013-10-12 23:04:27 -0700
committerJoshua Harlow <harlowja@gmail.com>2013-10-12 23:13:10 -0700
commitee83a3ff6f0b16b37c9fbfb634857a659a4205ad (patch)
tree20f2bdec06ef444f84bd058d894ebe14b6707f0c /taskflow/patterns/unordered_flow.py
parentfaf2d155dfc3d9225a4def5c492c37a9c7d18c5d (diff)
downloadtaskflow-ee83a3ff6f0b16b37c9fbfb634857a659a4205ad.tar.gz
Pattern comment additions/adjustments
Change-Id: I3154d1c228474d8699f3ae4d0be2fb46406a2f41
Diffstat (limited to 'taskflow/patterns/unordered_flow.py')
-rw-r--r--taskflow/patterns/unordered_flow.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/taskflow/patterns/unordered_flow.py b/taskflow/patterns/unordered_flow.py
index c66f2e8..3f517be 100644
--- a/taskflow/patterns/unordered_flow.py
+++ b/taskflow/patterns/unordered_flow.py
@@ -27,7 +27,8 @@ class Flow(flow.Flow):
executed in any order as one unit and rolled back as one unit.
NOTE(harlowja): Since the flow is unordered there can *not* be any
- dependency between task inputs and task outputs.
+ dependency between task/flow inputs (requirements) and
+ task/flow outputs (provided names/values).
"""
def __init__(self, name, uuid=None):